// AUTO-GENERATED BY UpdateGenVersion.bat dc90ed03c079632f04dff7ef9cf228eabe8891cc
const char GenVersion_Version[] = "0.4.4-dev";
const char GenVersion_Commit[] = "dc90ed03c079632f04dff7ef9cf228eabe8891cc";
